@@ -10,6 +10,8 @@ from functools import reduce
 from typing import List, Dict
 from .utils import copy_repeat, check_create_folder
 
+import gc
+
 
 class Pipeline:
     '''
@@ -77,7 +79,7 @@ class Pipeline:
     #     return pipeline
     #
 
-    def fit(self, index: List[str], metric):
+    def fit(self, index: List[str], metric=None):
         '''     
         Interface to fit pipeline model for tickers.
         Features and target will be based on data from data_loader
@@ -109,9 +111,10 @@ class Pipeline:
             X_ = X[leave_mask.values]
             self.core['model'][k].fit(X_, y_['y'])
             
-            pred = self.core['model'][k].predict(X_)
-            metric_name = 'metric_{}'.format(self.out_name[k])
-            metrics_result[metric_name] = metric[k](y_['y'].values, pred)
+            if metric[0] is not None:
+                pred = self.core['model'][k].predict(X_)
+                metric_name = 'metric_{}'.format(self.out_name[k])
+                metrics_result[metric_name] = metric[k](y_['y'].values, pred)
             
         return metrics_result
 
@@ -175,7 +178,6 @@ class Pipeline:
 
 
 
-
 class MergePipeline:
     '''
     Class combining list of pipelines to single pipilene.
@@ -212,7 +214,18 @@ class MergePipeline:
             pipeline.fit(index)
 
 
-    def execute(self, index) -> pd.DataFrame:
+    def _single_batch(self, batch):
+        dfs = []
+        for pipeline in self.pipeline_list:
+            dfs.append(pipeline.execute(batch))
+            
+        batch_result = reduce(lambda l, r: pd.merge(
+            l, r, on=self.execute_merge_on, how='left'), dfs)
+
+        return batch_result
+
+
+    def execute(self, index, batch_size=None) -> pd.DataFrame:
         '''     
         Interface for executing pipeline for tickers.
         Features will be based on data from data_loader
@@ -221,61 +234,66 @@ class MergePipeline:
         ----------
         index:
             identifiers for executing pipelines. I.e. list of companies tickers 
+        batch_size:
+            size of batch for execute separation(may be usefull
+            for lower memory usage).
+            OR ``None`` (for full-size executing)
 
         Returns
         -------
         ``pd.DataFrame``
             combined pipelines execute result
-        '''   
-        dfs = []
-        for pipeline in self.pipeline_list:
-            curr_df = pipeline.execute(index)
-            dfs.append(curr_df)
-            
-        result_df = reduce(lambda l, r: pd.merge(
-            l, r, on=self.execute_merge_on, how='left'), dfs)
+        '''
+        if batch_size is None:
+            batch_size = len(index)
+        batches = [index[k:k+batch_size] 
+                    for k in range(0, len(index), batch_size)]
+        result = []
+        for batch in batches:
+            result.append(self._single_batch(batch))
+           
+        result = pd.concat(result, axis=0)
 
-        return result_df
+        return result
             
             
-class QuarterlyLoadPipeline:
+class LoadingPipeline:
     '''
-    Wrapper for data_loader for loading quarterly data
-    in ``execute(data_loader, tickers:List[str]) -> pd.DataFrame``
+    Wrapper for data loaders for loading data
+    in ``execute(index) -> pd.DataFrame``
     interface
     '''
-    def __init__(self, columns:List[str]):
+    def __init__(self, data_loader, columns:List[str]):
         '''     
-        Parameters
-        ----------
-        columns:
-            column names for loading
-        '''
-        self.columns = columns
-       
-    def fit(self, data_loader, tickers:List[str]):
-        None
-
-    def execute(self, data_loader, tickers:List[str]):
-        '''     
-        Interface for executing pipeline(lading data) for
-        tickers using data_loader.
-        
         Parameters
         ----------
         data_loader:
-            class implements ``load_quarterly_data(tickers: List[str])``
-            -> pd.DataFrame`` interface
-            
-        tickers:
-            tickers of companies to load data for      
+            class implements ``load(index) -> pd.DataFrame`` interface
+        columns:
+            column names for loading
+        '''
+        self.data_loader = data_loader
+        self.columns = columns
+       
+    def fit(self, index):
+        None
+
+    def execute(self, index):
+        '''     
+        Interface for executing pipeline(lading data) for
+        tickers.
+        
+        Parameters
+        ----------
+        index:
+            inentification for loading data, i.e. list of tickers
                       
         Returns
         -------
         ``pd.DataFrame``
-            quarterly data
+            resulted data
         '''  
-        quarterly_data = data_loader.load_quarterly_data(tickers)
+        quarterly_data = self.data_loader.load(index)
         quarterly_df = quarterly_data[self.columns]
         return quarterly_df            
             
