@@ -3,15 +3,18 @@ import os
 import numpy as np
 import pandas as pd
 from ml_investment.utils import load_config, load_tickers, check_create_folder
-from ml_investment.data import SF1Data, QuandlCommoditiesData, ComboData
-from ml_investment.pipelines import BasePipeline, MergePipeline, \
-                                    QuarterlyLoadPipeline
+from ml_investment.data_loaders.sf1 import SF1QuarterlyData, SF1DailyData
+from ml_investment.pipelines import MergePipeline, LoadingPipeline
+from ml_investment.applications.fair_marketcap_sf1 import FairMarketcapSF1
+from ml_investment.applications.fair_marketcap_diff_sf1 import FairMarketcapDiffSF1
+from ml_investment.applications.marketcap_down_std_sf1 import MarketcapDownStdSF1
 
+config = load_config()
 
 
 def pipeline_postprocessing(quarterly_df):    
     quarterly_df['fair_marketcap_via_diff'] = quarterly_df.groupby('ticker')\
-        ['marketcap'].shift(-1) * (1 + quarterly_df['fair_marketcap_diff'])
+        ['marketcap'].shift(-1) * (1 + quarterly_df['fair_marketcap_diff_sf1'])
 
     quarterly_df['down70'] = quarterly_df['marketcap'] * \
                             (1 - quarterly_df['marketcap_down_std_sf1'] * 1.04)
@@ -33,7 +36,9 @@ def calc_metrics(quarterly_df):
     tmp = tmp.rename({'fm_m_ratio':'mean_fm_m_ratio'}, axis=1)
     metrics_df = pd.merge(metrics_df, tmp, on='ticker', how='left')
 
-    tmp = data_loader.load_daily_data(ticker_list, back_days=1)
+    tickers = q_df['ticker'].unique()
+    tmp = SF1DailyData(data_path=config['sf1_data_path'],
+                       days_count=1).load(tickers)
     tmp = tmp[['ticker', 'marketcap', 'pe']]
     tmp['last_marketcap'] = tmp['marketcap'].astype(float)
     del tmp['marketcap']
@@ -51,27 +56,20 @@ def calc_metrics(quarterly_df):
     return metrics_df
 
 
-if __name__ == '__main__':
-    config = load_config()
- 
-    dl1 = SF1Data(config['sf1_data_path'])
-    dl2 = QuandlCommoditiesData(config['commodities_data_path'])
-    data_loader = ComboData([dl1, dl2])
+def main():
+    tickers = load_tickers()['base_us_stocks']    
+
+    p1 = FairMarketcapSF1()
+    p2 = FairMarketcapDiffSF1()
+    p3 = MarketcapDownStdSF1()
+    p4 = LoadingPipeline(SF1QuarterlyData(config['sf1_data_path']),
+                         ['ticker', 'date', 'marketcap'])
 
-    ticker_list = load_tickers()['base_us_stocks']
-    
     pipeline = MergePipeline(
-        pipeline_list=[
-            BasePipeline.load('{}/fair_marketcap_sf1.pickle'.format(
-                                                    config['models_path'])),
-            BasePipeline.load('{}/fair_marketcap_diff_sf1.pickle'.format(
-                                                    config['models_path'])),
-            BasePipeline.load('{}/marketcap_down_std_sf1.pickle'.format(
-                                                    config['models_path'])),
-            QuarterlyLoadPipeline(['ticker', 'date', 'marketcap'])],
+        pipeline_list=[p1, p2, p3, p4],
         execute_merge_on=['ticker', 'date'])
 
-    quarterly_df = pipeline.execute(data_loader, ticker_list)
+    quarterly_df = pipeline.execute(tickers)
     quarterly_df = pipeline_postprocessing(quarterly_df)
 
     metrics_df = calc_metrics(quarterly_df)
@@ -86,6 +84,10 @@ if __name__ == '__main__':
 
 
 
+if __name__ == '__main__':
+    main()
+
+
 
 
 
